@@ -28,7 +28,12 @@ class TooManyRequestsException(DeepLException):
 
 
 class ConnectionException(DeepLException):
-    """Connection to the DeepL API failed."""
+    """Connection to the DeepL API failed.
+
+    :param message: Message describing the error that occurred.
+    :param should_retry: True if the request would normally be retried
+        following this error, otherwise false.
+    """
 
     def __init__(
         self,
@@ -40,14 +45,28 @@ class ConnectionException(DeepLException):
 
 
 class DocumentTranslationException(DeepLException):
-    """Error occurred while translating document."""
+    """Error occurred while translating document.
 
-    def __init__(self, message, document_request):
+    :param message: Message describing the error that occurred.
+    :param document_handle: The document handle of the associated document.
+    """
+
+    def __init__(self, message, document_handle):
         super().__init__(message)
-        self.document_request = document_request
+        self.document_handle = document_handle
 
     def __str__(self):
-        return f"{super()}, document request: {self.document_request}"
+        return f"{super().__str__()}, document handle: {self.document_handle}"
+
+    @property
+    def document_request(self):
+        """Deprecated, use document_handle instead."""
+        import warnings
+
+        warnings.warn(
+            "document_request is deprecated", DeprecationWarning, stacklevel=2
+        )
+        return self.document_handle
 
 
 class GlossaryNotFoundException(DeepLException):
